@@ -27,29 +27,27 @@
 #include "Profile.h"
 
 class KCmdLineArgs;
-class KUrl;
 
 namespace Konsole
 {
-class ProfileList;
-class ViewManager;
 class MainWindow;
 class Session;
 
 /**
  * The Konsole Application.
  *
- * The application consists of one or more main windows and a set of factories to create
- * new sessions and views.
+ * The application consists of one or more main windows and a set of
+ * factories to create new sessions and views.
  *
- * To create a new main window with a default terminal session, call the newInstance() method.
- * Empty main windows can be created using newMainWindow().
+ * To create a new main window with a default terminal session, call
+ * the newInstance(). Empty main windows can be created using newMainWindow().
  *
- * The factory used to create new terminal sessions can be retrieved using the sessionManager() accessor.
+ * The factory used to create new terminal sessions can be retrieved using
+ * the sessionManager() accessor.
  */
 class Application : public KUniqueApplication
 {
-Q_OBJECT
+    Q_OBJECT
 
 public:
     /** Constructs a new Konsole application. */
@@ -67,31 +65,21 @@ public:
      */
     MainWindow* newMainWindow();
 
-    /** Returns the Application instance */
-    static Application* self();
-
 private slots:
-    Session* createSession(Profile::Ptr profile, const QString& directory , ViewManager* view);
-    Session* createSSHSession(Profile::Ptr profile, const KUrl& url, ViewManager* view);
     void createWindow(Profile::Ptr profile , const QString& directory);
     void detachView(Session* session);
 
-    void toggleBackgroundInstance();
-
 private:
     void init();
     void listAvailableProfiles();
     void listProfilePropertyInfo();
-    void startBackgroundMode(MainWindow* window);
     bool processHelpArgs(KCmdLineArgs* args);
     MainWindow* processWindowArgs(KCmdLineArgs* args);
-    void processProfileSelectArgs(KCmdLineArgs* args,MainWindow* window);
-    void processProfileChangeArgs(KCmdLineArgs* args,MainWindow* window);
+    Profile::Ptr processProfileSelectArgs(KCmdLineArgs* args);
+    Profile::Ptr processProfileChangeArgs(KCmdLineArgs* args, Profile::Ptr baseProfile);
     void processTabsFromFileArgs(KCmdLineArgs* args, MainWindow* window);
-    void createTabFromArgs(KCmdLineArgs* args, MainWindow* window, const QHash<QString, QString>&);
-
-    MainWindow* _backgroundInstance;
+    void createTabFromArgs(KCmdLineArgs* args, MainWindow* window,
+                           const QHash<QString, QString>&);
 };
-
 }
-#endif //APPLICATION_H
+#endif  // APPLICATION_H
